#<profile4xi profile = "02" /> 
# -------------------------------------------------------------------------------------------------
#<program4xi program = "synchronizedarray4xi.py">
#<abstract4xi abstract = "provides class SynchronizedArray4Xi"/>
#<refer4xi reference = "sharedctypes.py"/> 
#<state4xi status = "ACK4tagging; ACK4moduletesting; NACK4systemtesting; [Rel 7.21]"/>
# -------------------------------------------------------------------------------------------------

# -------------------------------------------------------------------------------------------------
# Public API
# -------------------------------------------------------------------------------------------------
#<interface4xi interface = " 
__all__ = [ 'SynchronizedArray4Xi' ] 
#"
#/>

# -------------------------------------------------------------------------------------------------
# Standard Imports                          
# -------------------------------------------------------------------------------------------------
#<standardize4xi standard = "
try:                 # system ones
    import os
    import sys
    import signal
except:
    pass
try:                 # threading ones       
    import threading                
    import _thread   
except:
    pass
try:
    import _winapi
except:
    pass

                
try:                 # most-common ones
    import weakref         
except:
    pass
try:                 # rare ones
    import ctypes          
except:
    pass 
try:                 # imported-as ones 
    pass          
except:
    pass            
#"
#/>

# -------------------------------------------------------------------------------------------------
# Multiprocessing Imports                          
# -------------------------------------------------------------------------------------------------
#<process4xi process = "
try:                             # Binary ones
    import _multiprocessing
except:
    pass
try:                             # Python ones
    pass
except:
    pass
#"
#/>

# -------------------------------------------------------------------------------------------------
# DragonXi imports                              
# -------------------------------------------------------------------------------------------------
#<dragonize4xi dragonization = "
from ace_object4xi import ace_object4xi
from print4xi import print4xi
from reason_object4xi import reason_object4xi
from sense_object4xi import sense_object4xi
from synchronizedbase4xi import SynchronizedBase4Xi
from time4xi import time4xi
#"
#/>


# =================================================================================================
#<class4xi class = "SynchronizedArray4Xi" base = "SynchronizedBase4Xi" child = "None" 
#  synopsis = "Offers synchronized array services"
#  usage = "
#     managers.py:
#         elif isinstance(obj, ctypes.Array):
#              return SynchronizedArray(obj, lock)
#
#     synchronizedstring4xi.py:
#         SynchronizedArray4Xi.__init__(self)
#             return SynchronizedArray4Xi.__len__(self)
#             return SynchronizedArray4Xi.__getitem__(self, i)
#         SynchronizedArray4Xi.__setitem__(self, i, value)
#             return SynchronizedArray4Xi.__getslice__(self, start, stop)
#         SynchronizedArray4Xi.__setslice__(self, start, stop, values)
#
#     synchronized_function4xi.py:
#         return SynchronizedArray4Xi(obj, lock)
#
#"
#>
#<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
# =================================================================================================
class SynchronizedArray4Xi(SynchronizedBase4Xi):
    '''
    Offers synchronized array services
    '''
    
    # ---------------------------------------------------------------------------------------------
    # Public API of this class
    # ---------------------------------------------------------------------------------------------    
    #<expose4xi expose = "
    _exposed_ = ('sense', 'reason', 'ace')          
    #"
    #/>
           
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "len-of-SynchronizedArray4Xi" usage = "returns length">
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/>                             
    # ---------------------------------------------------------------------------------------------
    def __len__(self):
        '''
        SynchronizedArray4Xi method __len__: returns length
        '''
        # -----------------------------------------------------------------------------------------    
        #
        # -----------------------------------------------------------------------------------------         
        class2print = "SynchronizedArray4Xi"
        method2print = "__len__"
        
        message2print = "{started" + "; len-of-SynchronizedArray4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
                             
        
        # -----------------------------------------------------------------------------------------    
        #
        # -----------------------------------------------------------------------------------------                 
        
        message2print = "{returning" + "; len-object-of-synchronizedarray2xi-returning-by-len-of-SynchronizedArray4Xi: " + str(len(self._obj)) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)    
                                
                   
        return len(self._obj)
    #</methodize4xi>
            
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "getitem-of-SynchronizedArray4Xi" usage = "gets item with (self, i)">
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/>                              
    # ---------------------------------------------------------------------------------------------
    def __getitem__(self, i):
        '''
        gets item with (self, i)  
        ''' 
        # -----------------------------------------------------------------------------------------    
        # (Step 1/3)
        # -----------------------------------------------------------------------------------------                
        class2print = "SynchronizedArray4Xi"
        method2print = "__getitem__"
        
        message2print = "{(Step 1/3a) started" + "; getitem-of-SynchronizedArray4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
     
        message2print = "{(Step 1/3b) passed" + "; index-passed-to-getitem-of-SynchronizedArray4Xi: " + str(i) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)          
        
        # -----------------------------------------------------------------------------------------    
        # (Step 2/3)
        # -----------------------------------------------------------------------------------------                 
        try:
            self.acquire()
    
            message2print = "{(Step 2/3a) acquired" + "; acquired-of-synchronizedarray2xi-by-getitem-of-SynchronizedArray4Xi: " + str(self.acquire) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)    
        except:
            message2print = "{(Step 2/3b) yielded" + "; acquire-of-synchronizedarray2xi-yielded-by-getitem-of-SynchronizedArray4Xi: " + str(self.acquire)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print) 
                    
                                
        # -----------------------------------------------------------------------------------------    
        # (Step 3/3)
        # -----------------------------------------------------------------------------------------                 
           
        try:
            message2print = "{(Step 3/3a) returning" + "; object-of-synchronizedarray2xi-returning-by-getitem-of-SynchronizedArray4Xi: " + str(self._obj[i]) + "; time: " + time4xi() + "}" 
            print4xi(class2print, method2print, message2print)    
                                                      
        
            return self._obj[i]
        finally:
            self.release()
            
            message2print = "{(Step 3/3b) performed" + "; release-of-synchronizedarray2xi-performed-by-getitem-of-SynchronizedArray4Xi: " + str(self.release) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)             
                            
        

    #</methodize4xi>
                 
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "setitem-of-SynchronizedArray4Xi" usage = "sets item with (self, i, value)">
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/>                          
    # ---------------------------------------------------------------------------------------------
    def __setitem__(self, i, value):
        '''
        sets item with (self, i, value) 
        '''
          
        # -----------------------------------------------------------------------------------------    
        # (Step 1/3)
        # -----------------------------------------------------------------------------------------                 
            
        class2print = "SynchronizedArray4Xi"
        method2print = "__setitem__"
        
        message2print = "{(Step 1/3a) started" + "; setitem-of-SynchronizedArray4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
                
        message2print = "{(Step 1/3b) passed" + "; index-passed-to-setitem-of-SynchronizedArray4Xi: " + str(i) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                  
           
                
        message2print = "{(Step 1/3c) passed" + "; value-passed-to-setitem-of-SynchronizedArray4Xi: " + str(value) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                  
          
        # -----------------------------------------------------------------------------------------    
        # (Step 2/3)
        # ----------------------------------------------------------------------------------------- 
                        
        try:   
            self.acquire()
            
            message2print = "{(Step 2/3a) acquired" + "; synchronizedarray2xi-acquired-by-setitem-of-SynchronizedArray4Xi: " + str(self.acquire) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print) 
        except:
            message2print = "{(Step 2/3b) yielded" + "; acquire-of-synchronizedarray2xi-yielded-by-setitem-of-SynchronizedArray4Xi: " + str(self.acquire)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print) 
        
          
        # -----------------------------------------------------------------------------------------    
        # 
        # ----------------------------------------------------------------------------------------- 
            
        try:
            self._obj[i] = value
            
            message2print = "{(Step 2/3b) set" + "; object-of-synchronizedarray2xi-set-by-setitem-of-SynchronizedArray4Xi to: " + str(self._obj[i])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)    
        except:
            message2print = "{(Step 2/3c) yielded" + "; object-of-synchronizedarray2xi-yielded-by-setitem-of-SynchronizedArray4Xi: " + str(self._obj)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print) 
                            
          
        # -----------------------------------------------------------------------------------------    
        # 
        # ----------------------------------------------------------------------------------------- 
                                
            
        finally:
            self.release()
            
            message2print = "{released" + "; synchronizedarray2xi-released-by-setitem-of-SynchronizedArray4Xi: " + str(self.release) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            
            
            
            
        # -----------------------------------------------------------------------------------------    
        # (Step 3/3)
        # -----------------------------------------------------------------------------------------                 
        message2print = "{(Step 3/3) returning" + "; setitem-of-SynchronizedArray4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
                                
        return                
                                
    #</methodize4xi>
                        
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "getslice-of-SynchronizedArray4Xi" usage = "gets slice with (self, start, stop)">
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/>                         
    # ---------------------------------------------------------------------------------------------
    def __getslice__(self, start, stop):
        '''
        gets slice with (self, start, stop)
        '''
          
        # -----------------------------------------------------------------------------------------    
        # (Step 1/2)
        # -----------------------------------------------------------------------------------------                 
            
        class2print = "SynchronizedArray4Xi"
        method2print = "__getslice__"
        
        message2print = "{(Step 1/2a) started" + "; getslice-of-SynchronizedArray4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
     
                
        message2print = "{(Step 1/2b) passed" + "; start-passed-to-getslice-of-SynchronizedArray4Xi: " + str(start) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                  
                
        message2print = "{(Step 1/2c) passed" + "; stop-passed-to-getslice-of-SynchronizedArray4Xi: " + str(stop) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                  
            
        # -----------------------------------------------------------------------------------------    
        # (Step 2/2)
        # -----------------------------------------------------------------------------------------
                         
        try:   
            self.acquire()
            
            message2print = "{(Step 2/2a) acquired" + "; synchronizedarray2xi-acquired-by-getslice-of-SynchronizedArray4Xi: " + str(self.acquire) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print) 
        except:
            message2print = "{(Step 2/2a) yielded" + "; acquire--of-synchronizedarray2xi-yielded-by-getslice-of-SynchronizedArray4Xi: " + str(self.acquire)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print) 
           
            
        # -----------------------------------------------------------------------------------------    
        # 
        # -----------------------------------------------------------------------------------------
              
        try:

            message2print = "{(Step 2/2b) returning" + "; object-start-stop-of-synchronizedarray2xi-returning-by-getslice-of-SynchronizedArray4Xi: " + str(self._obj[start:stop]) + "; time: " + time4xi() + "}" 
            print4xi(class2print, method2print, message2print)    
                                          
        
            return self._obj[start:stop]
        except:
        
            message2print = "{(Step 2/2c) yielded" + "; object-of-synchronizedarray2xi-yielded-by-getslice-of-SynchronizedArray4Xi: " + str(self._obj)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print) 
        
                
        # -----------------------------------------------------------------------------------------    
        #
        # -----------------------------------------------------------------------------------------
                  
        finally:
            self.release()
            
            
            message2print = "{(Step 2/2d) released" + "; synchronizedarray2xi-released-by-getslice-of-SynchronizedArray4Xi: " + str(self.release) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
              
            
            
        
  
    #</methodize4xi>
                       
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "setslice-of-SynchronizedArray4Xi" usage = "sets slice with (self, start, stop, values) ">
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/>                      
    # ---------------------------------------------------------------------------------------------
    def __setslice__(self, start, stop, values):
        '''
        sets slice with (self, start, stop, values) 
        '''
          
        # -----------------------------------------------------------------------------------------    
        # (Step 1/3)
        # -----------------------------------------------------------------------------------------                 
            
        class2print = "SynchronizedArray4Xi"
        method2print = "__setslice__"
        
        message2print = "{(Step 1/3a) started" + "; setslice-of-SynchronizedArray4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
                
        message2print = "{(Step 1/3b) passed" + "; start-passed-to-setslice-of-SynchronizedArray4Xi: " + str(start) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                  
                
        message2print = "{(Step 1/3c) passed" + "; stop-passed-to-setslice-of-SynchronizedArray4Xi: " + str(stop) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                  
             
                
        message2print = "{(Step 1/3d) passed" + "; values-passed-to-setslice-of-SynchronizedArray4Xi: " + str(values) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                  
          
        # -----------------------------------------------------------------------------------------    
        # (Step 2/3)
        # ----------------------------------------------------------------------------------------- 
                        
        try:  
            self.acquire()
            
            message2print = "{(Step 2/3a) acquired" + "; synchronizedarray2xi-acquired-by-setslice-of-SynchronizedArray4Xi: " + str(self.acquire) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print) 
        except:
            message2print = "{(Step 2/3b) yielded" + "; acquire-of-synchronizedarray2xi-yielded-by-setslice-of-SynchronizedArray4Xi: " + str(self.acquire)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print) 
        
          
        # -----------------------------------------------------------------------------------------    
        # 
        # ----------------------------------------------------------------------------------------- 
                     
        try:
        
            self._obj[start:stop] = values
            
            message2print = "{(Step 2/3c) set" + "; object-start-stop-of-synchronizedarray2xi-set-by-setslice-of-SynchronizedArray4Xi to: " + str(self._obj[start:stop])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)    
        except:
            message2print = "{(Step 2/3d) yielded" + "; object-yielded-by-setslice-of-SynchronizedArray4Xi: " + str(self._obj)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print) 
                            
          
        # -----------------------------------------------------------------------------------------    
        # 
        # ----------------------------------------------------------------------------------------- 
                                 
        finally:
            self.release()
            
            message2print = "{(Step 2/3e) released" + "; synchronizedarray2xi-released-by-setslice-of-SynchronizedArray4Xi: " + str(self.release) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
  
                    
        # -----------------------------------------------------------------------------------------    
        # (Step 3/3)
        # -----------------------------------------------------------------------------------------                 
        message2print = "{(Step 3/3) returning" + "; setslice-of-SynchronizedArray4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
                                
                        
                                
    #</methodize4xi>
                
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "sense-of-SynchronizedArray4Xi" usage = "senses SynchronizedArray4Xi class objects">
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/>     
    # ---------------------------------------------------------------------------------------------
    def sense(self):
        '''
        senses SynchronizedArray4Xi class objects
        '''
 
        
        class2print = 'SynchronizedArray4Xi'
        method2print = 'sense'
        
        
        message2print = "{started" + "; sense-of-SynchronizedArray4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
   
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------  
        message2print = "{sensing" + "; SynchronizedArray4Xi-sensing-by-sense-of-SynchronizedArray4Xi: " + str(SynchronizedArray4Xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
                    
        
        # -----------------------------------------------------------------------------------------
        # get sensed knowledge for this object
        # -----------------------------------------------------------------------------------------        
        kb2xi = sense_object4xi(self)
        
        message2print = "{got" + "; kb2xi-got-by-sense-of-SynchronizedArray4Xi: " + str(kb2xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
                
        
        # -----------------------------------------------------------------------------------------
        # add knowledge specific to this object
        # -----------------------------------------------------------------------------------------         
        try:
            kb2xi['acquire-of-synchronizedarray2xi'] = self.acquire
            kb2xi['release-of-synchronizedarray2xi'] = self.release        
            kb2xi['object-of-synchronizedarray2xi'] = self._obj            
      
        except:
            kb2xi['time-of-synchronizedarray2xi'] = time4xi()
        
            message2print = "{yielded" + "; kb2xi-yielded-by-sense-of-SynchronizedArray4Xi: " + str(kb2xi)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print) 

        message2print = "{sensed" + "; SynchronizedArray4Xi-sensed-by-sense-of-SynchronizedArray4Xi: " + str(SynchronizedArray4Xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print) 
                   
        # -----------------------------------------------------------------------------------------
        # 
        # -----------------------------------------------------------------------------------------         
        message2print = "{returning" + "; kb2xi-returning-by-sense-of-SynchronizedArray4Xi: " + str(kb2xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)    
                              
          
        return kb2xi
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------        
    #</methodize4xi>
    
        
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "reason-of-SynchronizedArray4Xi" usage = "reasons SynchronizedArray4Xi class objects">
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/>     
    # ---------------------------------------------------------------------------------------------
    def reason(self):
        '''
        method reason: reasons SynchronizedArray4Xi class objects
        '''
  
        
        class2print = 'SynchronizedArray4Xi'
        method2print = 'reason'

        
        message2print = "{started" + "; reason-of-SynchronizedArray4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
       
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------
        message2print = "{reasoning" + "; SynchronizedArray4Xi-reasoning-by-reason-of-SynchronizedArray4Xi: " + str(SynchronizedArray4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print) 
                
        
        # -----------------------------------------------------------------------------------------
        # get reasoned knowledge for this object
        # -----------------------------------------------------------------------------------------         
        kb4xi = reason_object4xi(self)
        
        
        message2print = "{got" + "; kb4xi-got-by-reason-of-SynchronizedArray4Xi: " + str(kb4xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
                
        
        # -----------------------------------------------------------------------------------------
        # add knowledge specific to this object
        # format example: kb4xi['time2xi'] = time4xi() #adding time 
        # -----------------------------------------------------------------------------------------          
        
        
          
        
        message2print = "{reasoned" + "; SynchronizedArray4Xi-reasoned-by-reason-of-SynchronizedArray4Xi: " + str(SynchronizedArray4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------        
        message2print = "{returning" + "; kb4xi-returning-by-reason-of-SynchronizedArray4Xi: " + str(kb4xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)    
                                
          
        return kb4xi
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------            
    #</methodize4xi>
    
    
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "ace-of-SynchronizedArray4Xi" usage = "aces SynchronizedArray4Xi class objects">
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/>     
    # ---------------------------------------------------------------------------------------------
    def ace(self):
        '''
        method ace: aces SynchronizedArray4Xi class objects 
        '''
   
        
        
        class2print = 'SynchronizedArray4Xi'
        method2print = 'ace'
        
        
        message2print = "{started" + "; ace-of-SynchronizedArray4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
             
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------
        message2print = "{acing" + "; SynchronizedArray4Xi-acing-by-ace-of-SynchronizedArray4Xi: " + str(SynchronizedArray4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
                     
        
        # -----------------------------------------------------------------------------------------
        # get aced knowledge for this object
        # -----------------------------------------------------------------------------------------        
        kb8xi = ace_object4xi(self)  
        
        message2print = "{got" + "; kb8xi-got-by-ace-of-SynchronizedArray4Xi: " + str(kb8xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
                

        # -----------------------------------------------------------------------------------------
        # add knowledge specific to this object
        # format example: kb8xi['time2xi'] = time4xi() #adding time 
        # -----------------------------------------------------------------------------------------              
        
          
        message2print = "{aced" + "; SynchronizedArray4Xi-aced-by-ace-of-SynchronizedArray4Xi: " + str(SynchronizedArray4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)        
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------        
        message2print = "{returning" + "; kb8xi-returning-by-ace-of-SynchronizedArray4Xi: " + str(kb8xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)    
                                 
        
        return kb8xi
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------            
    #</methodize4xi>
#</class4xi>
#</program4xi>

# -------------------------------------------------------------------------------------------------
# Recorded History                             
# ------------------------------------------------------------------------------------------------- 
#<record4xi record = "
#   test_none4xi.txt
#   sense-test-none4xi.xml
#   reason-test-none4xi.xml
#   ace-test-none4xi.xml
#"
#>

# -------------------------------------------------------------------------------------------------
# Legal Notice                             
# ------------------------------------------------------------------------------------------------- 
#<protect4xi protection = "copyright"
#   owner = "Small & Smart"
#   rights = "All rights reserved"
#   state = "California"
#   country = "United States of America"
#   references = "Legal notice at www.dragonxi.com; www.yourdragonxi.com; www.yourdragonxi.org; www.dragon2xi.com/; www.dragon4xi.com/; www.dragon8xi.com/ " 
#   codes = "Codes established in California and applicable to corporations in California"
#   compliance = "The California Law"
#   court = "Supreme Court of California, 350 McAllister Street, San Francisco, CA 94102-4783"
#/>
 

#<end4xi end = "
# -------------------------------------------------------------------------------------------------
# end of synchronizedarray4xi.py                             
# ------------------------------------------------------------------------------------------------- 
#"
#/>
